@@ -46,6 +46,8 @@
 
 #define FILE_ARRAY_INITIAL_SIZE	256
 #define PROGRESS_DELAY          50
+#define BYTES_FRACTION(self)    ((double) (self)->priv->completed_bytes / (self)->priv->total_bytes)
+#define FILES_FRACTION(self)    ((double) (self)->priv->completed_files + 0.5) / ((self)->priv->total_files + 1)
 
 
 char *action_names[] = { "NONE",
@@ -441,11 +443,11 @@ fr_archive_init (FrArchive *self)
         self->multi_volume = FALSE;
         self->volume_size = 0;
 	self->read_only = FALSE;
-        self->extract_here = FALSE;
 
         self->propAddCanUpdate = FALSE;
         self->propAddCanReplace = FALSE;
         self->propAddCanStoreFolders = FALSE;
+        self->propAddCanStoreLinks = FALSE;
         self->propExtractCanAvoidOverwrite = FALSE;
         self->propExtractCanSkipOlder = FALSE;
         self->propExtractCanJunkPaths = FALSE;
@@ -1001,6 +1003,7 @@ typedef struct {
 	GFile               *base_dir;
 	char                *dest_dir;
 	gboolean             update;
+	gboolean             follow_links;
 	char                *password;
 	gboolean             encrypt_header;
 	FrCompression        compression;
@@ -1082,7 +1085,7 @@ fr_archive_add_files_ready_cb (GList    *file_info_list, /* FileInfo list */
 								   add_data->base_dir,
 								   add_data->dest_dir,
 								   add_data->update,
-								   FALSE,
+								   add_data->follow_links,
 								   add_data->password,
 								   add_data->encrypt_header,
 								   add_data->compression,
@@ -1106,6 +1109,7 @@ fr_archive_add_files (FrArchive           *archive,
 		      GFile               *base_dir,
 		      const char          *dest_dir,
 		      gboolean             update,
+		      gboolean             follow_links,
 		      const char          *password,
 		      gboolean             encrypt_header,
 		      FrCompression        compression,
@@ -1124,6 +1128,7 @@ fr_archive_add_files (FrArchive           *archive,
 	add_data->base_dir = _g_object_ref (base_dir);
 	add_data->dest_dir = g_strdup (dest_dir);
 	add_data->update = update;
+	add_data->follow_links = follow_links;
 	add_data->password = g_strdup (password);
 	add_data->encrypt_header = encrypt_header;
 	add_data->compression = compression;
@@ -1180,6 +1185,7 @@ file_filter_cb (GFile     *file,
 
 void
 fr_archive_add_files_with_filter (FrArchive           *archive,
+				  GList               *file_list,
 				  GFile               *source_dir,
 				  const char          *include_files,
 				  const char          *exclude_files,
@@ -1195,8 +1201,8 @@ fr_archive_add_files_with_filter (FrArchive           *archive,
 				  GAsyncReadyCallback  callback,
 				  gpointer             user_data)
 {
-	AddData *add_data;
-	GList   *file_list;
+	AddData       *add_data;
+	FileListFlags  flags;
 
 	g_return_if_fail (! archive->read_only);
 
@@ -1205,6 +1211,7 @@ fr_archive_add_files_with_filter (FrArchive           *archive,
 	add_data->base_dir = _g_object_ref (source_dir);
 	add_data->dest_dir = g_strdup (dest_dir);
 	add_data->update = update;
+	add_data->follow_links = follow_links;
 	add_data->password = g_strdup (password);
 	add_data->encrypt_header = encrypt_header;
 	add_data->compression = compression;
@@ -1218,9 +1225,11 @@ fr_archive_add_files_with_filter (FrArchive           *archive,
 
 	fr_archive_action_started (archive, FR_ACTION_GETTING_FILE_LIST);
 
-	file_list = g_list_prepend (NULL, source_dir);
+	flags = FILE_LIST_RECURSIVE | FILE_LIST_NO_BACKUP_FILES;
+	if (! follow_links)
+		flags |= FILE_LIST_NO_FOLLOW_LINKS;
 	_g_file_list_query_info_async (file_list,
-				       FILE_LIST_RECURSIVE | FILE_LIST_NO_BACKUP_FILES,
+				       flags,
 				       (G_FILE_ATTRIBUTE_STANDARD_NAME ","
 					G_FILE_ATTRIBUTE_STANDARD_SIZE ","
 					G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN ","
@@ -1230,8 +1239,6 @@ fr_archive_add_files_with_filter (FrArchive           *archive,
 				       file_filter_cb,
 				       fr_archive_add_files_ready_cb,
 				       add_data);
-
-	g_list_free (file_list);
 }
 
 
@@ -1321,6 +1328,110 @@ fr_archive_extract (FrArchive           *archive,
 /* -- fr_archive_extract_here -- */
 
 
+typedef struct {
+	FrArchive          *archive;
+	GCancellable       *cancellable;
+	GSimpleAsyncResult *result;
+} ExtractHereData;
+
+
+static void
+extract_here_data_free (ExtractHereData *e_data)
+{
+	_g_object_unref (e_data->cancellable);
+	g_object_unref (e_data->result);
+	g_free (e_data);
+}
+
+
+static void
+move_here (FrArchive    *archive,
+	   GCancellable *cancellable)
+{
+	GFile  *extraction_destination;
+	GFile  *directory_content;
+	GFile  *parent;
+	GFile  *parent_parent;
+	char   *content_name;
+	GFile  *new_directory_content;
+	GError *error = NULL;
+
+	extraction_destination = fr_archive_get_last_extraction_destination (archive);
+	directory_content = _g_file_get_dir_content_if_unique (extraction_destination);
+	if (directory_content == NULL)
+		return;
+
+	parent = g_file_get_parent (directory_content);
+
+	if (g_file_equal (parent, extraction_destination)) {
+		GFile *new_destination;
+
+		new_destination = _g_file_create_alternative_for_file (extraction_destination);
+		if (! g_file_move (extraction_destination, new_destination, 0, cancellable, NULL, NULL, &error)) {
+			g_warning ("%s", error->message);
+			g_clear_error (&error);
+		}
+
+		fr_archive_set_last_extraction_destination (archive, new_destination);
+
+		g_object_unref (directory_content);
+		directory_content = _g_file_get_dir_content_if_unique (new_destination);
+		g_object_unref (new_destination);
+
+		if (directory_content == NULL)
+			return;
+
+		g_object_unref (parent);
+		parent = g_file_get_parent (directory_content);
+	}
+
+	parent_parent = g_file_get_parent (parent);
+	content_name = g_file_get_basename (directory_content);
+	new_directory_content = _g_file_create_alternative (parent_parent, content_name);
+	g_free (content_name);
+
+	if (! g_file_move (directory_content, new_directory_content, 0, cancellable, NULL, NULL, &error)) {
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
+	}
+
+	if (! g_file_delete (parent, cancellable, &error)) {
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
+	}
+
+	fr_archive_set_last_extraction_destination (archive, new_directory_content);
+
+	g_object_unref (new_directory_content);
+	g_object_unref (parent_parent);
+	g_object_unref (parent);
+	g_object_unref (directory_content);
+}
+
+
+static void
+extract_here_ready_cb (GObject      *source_object,
+		       GAsyncResult *result,
+		       gpointer      user_data)
+{
+	ExtractHereData *e_data = user_data;
+	GError          *error = NULL;
+
+	fr_archive_operation_finish (FR_ARCHIVE (source_object), result, &error);
+	if (error != NULL) {
+		_g_file_remove_directory (fr_archive_get_last_extraction_destination (e_data->archive), NULL, NULL);
+		g_simple_async_result_set_from_error (e_data->result, error);
+		g_error_free (error);
+	}
+	else
+		move_here (e_data->archive, e_data->cancellable);
+
+	g_simple_async_result_complete_in_idle (e_data->result);
+
+	extract_here_data_free (e_data);
+}
+
+
 static char *
 get_desired_destination_for_archive (GFile *file)
 {
@@ -1405,26 +1516,31 @@ fr_archive_extract_here (FrArchive           *archive,
 			 GAsyncReadyCallback  callback,
 			 gpointer             user_data)
 {
-	GFile  *destination;
-	GError *error = NULL;
+	GSimpleAsyncResult *result;
+	GFile              *destination;
+	GError             *error = NULL;
+	ExtractHereData    *e_data;
+
+	result = g_simple_async_result_new (G_OBJECT (archive),
+					    callback,
+					    user_data,
+					    fr_archive_extract_here);
 
 	destination = get_extract_here_destination (archive->priv->file, &error);
 	if (error != NULL) {
-		GSimpleAsyncResult *result;
-
-		result = g_simple_async_result_new (G_OBJECT (archive),
-						    callback,
-						    user_data,
-						    fr_archive_extract_here);
 		g_simple_async_result_set_from_error (result, error);
 		g_simple_async_result_complete_in_idle (result);
 
+		g_object_unref (result);
 		g_error_free (error);
-
 		return FALSE;
 	}
 
-	archive->extract_here = TRUE;
+	e_data = g_new0 (ExtractHereData, 1);
+	e_data->archive = archive;
+	e_data->cancellable = _g_object_ref (cancellable);
+	e_data->result = result;
+
 	fr_archive_extract (archive,
 			    NULL,
 			    destination,
@@ -1434,8 +1550,8 @@ fr_archive_extract_here (FrArchive           *archive,
 			    junk_path,
 			    password,
 			    cancellable,
-			    callback,
-			    user_data);
+			    extract_here_ready_cb,
+			    e_data);
 
 	g_object_unref (destination);
 
@@ -1707,6 +1823,7 @@ add_dropped_items (DroppedItemsData *data)
 				      first_parent,
 				      data->dest_dir,
 				      FALSE,
+				      FALSE,
 				      data->password,
 				      data->encrypt_header,
 				      data->compression,
@@ -1739,6 +1856,7 @@ add_dropped_items (DroppedItemsData *data)
 				      parent,
 				      data->dest_dir,
 				      FALSE,
+				      FALSE,
 				      data->password,
 				      data->encrypt_header,
 				      data->compression,
@@ -1769,6 +1887,7 @@ add_dropped_items (DroppedItemsData *data)
 				      first_parent,
 				      data->dest_dir,
 				      FALSE,
+				      FALSE,
 				      data->password,
 				      data->encrypt_header,
 				      data->compression,
@@ -1827,6 +1946,7 @@ fr_archive_add_dropped_items (FrArchive           *archive,
 		g_simple_async_result_complete_in_idle (result);
 
 		g_error_free (error);
+		g_object_unref (result);
 		return;
 	}
 
@@ -1840,6 +1960,7 @@ fr_archive_add_dropped_items (FrArchive           *archive,
 			g_simple_async_result_complete_in_idle (result);
 
 			g_error_free (error);
+			g_object_unref (result);
 			return;
 		}
 	}
@@ -1857,6 +1978,8 @@ fr_archive_add_dropped_items (FrArchive           *archive,
 								    callback,
 								    user_data);
 	add_dropped_items (archive->priv->dropped_items_data);
+
+	g_object_unref (result);
 }
 
 
@@ -2010,7 +2133,7 @@ fr_archive_progress_inc_completed_files (FrArchive *self,
 	g_mutex_lock (&self->priv->progress_mutex);
 	self->priv->completed_files += new_completed;
 	if (self->priv->total_files > 0)
-		fraction = (double) self->priv->completed_files / (self->priv->total_files + 1);
+		fraction = FILES_FRACTION (self);
 	else
 		fraction = 0.0;
 	/*g_print ("%d / %d  : %f\n", self->priv->completed_files, self->priv->total_files + 1, fraction);*/
@@ -2040,7 +2163,7 @@ _set_completed_bytes (FrArchive *self,
 
 	self->priv->completed_bytes = completed_bytes;
 	if (self->priv->total_bytes > 0)
-		fraction = (double) self->priv->completed_bytes / (self->priv->total_bytes + 1);
+		fraction = BYTES_FRACTION (self);
 	else
 		fraction = 0.0;
 	/*g_print ("%" G_GSIZE_FORMAT " / %" G_GSIZE_FORMAT "  : %f\n", self->priv->completed_bytes, self->priv->total_bytes + 1, fraction);*/
@@ -2082,10 +2205,14 @@ fr_archive_progress_get_fraction (FrArchive *self)
 	double fraction;
 
 	g_mutex_lock (&self->priv->progress_mutex);
-	if ((self->priv->total_bytes > 0) && (self->priv->completed_bytes > 0))
-		fraction = (double) self->priv->completed_bytes / (self->priv->total_bytes + 1);
-	else if ((self->priv->total_files > 0) && (self->priv->completed_files > 0))
-		fraction = (double) self->priv->completed_files / (self->priv->total_files + 1);
+	if ((self->priv->total_bytes > 0) && (self->priv->completed_bytes > 0)) {
+		fraction = BYTES_FRACTION (self);
+		/*g_print ("%" G_GSIZE_FORMAT " / %" G_GSIZE_FORMAT "  : %f\n", self->priv->completed_bytes, self->priv->total_bytes + 1, fraction);*/
+	}
+	else if (self->priv->total_files > 0) {
+		fraction = FILES_FRACTION (self);
+		/*g_print ("%d / %d  : %f\n", self->priv->completed_files, self->priv->total_files + 1, fraction);*/
+	}
 	else
 		fraction = 0.0;
 	g_mutex_unlock (&self->priv->progress_mutex);
