@@ -46,7 +46,8 @@ typedef enum {
 	FR_ACTION_SAVING_REMOTE_ARCHIVE,      /* copying the archive to a remote location */
 	FR_ACTION_RENAMING_FILES,             /* renaming files stored in the archive */
 	FR_ACTION_PASTING_FILES,              /* pasting files from the clipboard into the archive */
-	FR_ACTION_UPDATING_FILES              /* updating the files modified with an external application */
+	FR_ACTION_UPDATING_FILES,             /* updating the files modified with an external application */
+	FR_ACTION_ENCRYPTING_ARCHIVE          /* saving the archive with a different password */
 } FrAction;
 
 #ifdef DEBUG
@@ -90,7 +91,6 @@ struct _FrArchive {
 
 	/*<protected>*/
 
-	gboolean       extract_here;
 	gssize         files_to_add_size;
 
 	/* features. */
@@ -114,6 +114,13 @@ struct _FrArchive {
 	 */
 	guint          propAddCanStoreFolders : 1;
 
+	/*
+	 * propAddCanStoreLinks
+	 *
+	 * TRUE if the command can store symbolic links
+	 */
+	guint          propAddCanStoreLinks : 1;
+
 	/* propExtractCanAvoidOverwrite:
 	 *
 	 * TRUE if the command can avoid to overwrite the files on disk.
@@ -229,7 +236,7 @@ struct _FrArchiveClass {
 					    GFile               *base_dir,
 					    const char          *dest_dir,
 					    gboolean             update,
-					    gboolean             recursive,
+					    gboolean             follow_links,
 					    const char          *password,
 					    gboolean             encrypt_header,
 					    FrCompression        compression,
@@ -344,6 +351,7 @@ void          fr_archive_add_files               (FrArchive           *archive,
 						  GFile               *base_dir,
 						  const char          *dest_dir,
 						  gboolean             update,
+						  gboolean             follow_links,
 						  const char          *password,
 						  gboolean             encrypt_header,
 						  FrCompression        compression,
@@ -352,6 +360,7 @@ void          fr_archive_add_files               (FrArchive           *archive,
 						  GAsyncReadyCallback  callback,
 						  gpointer             user_data);
 void          fr_archive_add_files_with_filter   (FrArchive           *archive,
+						  GList               *file_list, /* GFile list */
 						  GFile               *base_dir,
 						  const char          *include_files,
 						  const char          *exclude_files,
