@@ -56,7 +56,7 @@ typedef struct {
 	GFile              *base_dir;
 	char               *dest_dir;
 	gboolean            update;
-	gboolean            recursive;
+	gboolean            follow_links;
 	GFile              *tmp_dir;
 	guint               source_id;
 	char               *password;
@@ -189,71 +189,6 @@ copy_archive_to_remote_location (FrArchive          *archive,
 /* -- copy_extracted_files_to_destination -- */
 
 
-static void
-move_here (FrArchive    *archive,
-	   GCancellable *cancellable)
-{
-	GFile  *extraction_destination;
-	GFile  *directory_content;
-	GFile  *parent;
-	GFile  *parent_parent;
-	char   *content_name;
-	GFile  *new_directory_content;
-	GError *error = NULL;
-
-	extraction_destination = fr_archive_get_last_extraction_destination (archive);
-	directory_content = _g_file_get_dir_content_if_unique (extraction_destination);
-	if (directory_content == NULL)
-		return;
-
-	parent = g_file_get_parent (directory_content);
-
-	if (g_file_equal (parent, extraction_destination)) {
-		GFile *new_destination;
-
-		new_destination = _g_file_create_alternative_for_file (extraction_destination);
-		if (! g_file_move (extraction_destination, new_destination, 0, cancellable, NULL, NULL, &error)) {
-			g_warning ("%s", error->message);
-			g_clear_error (&error);
-		}
-
-		fr_archive_set_last_extraction_destination (archive, new_destination);
-
-		g_object_unref (directory_content);
-		directory_content = _g_file_get_dir_content_if_unique (new_destination);
-		g_object_unref (new_destination);
-
-		if (directory_content == NULL)
-			return;
-
-		g_object_unref (parent);
-		parent = g_file_get_parent (directory_content);
-	}
-
-	parent_parent = g_file_get_parent (parent);
-	content_name = g_file_get_basename (directory_content);
-	new_directory_content = _g_file_create_alternative (parent_parent, content_name);
-	g_free (content_name);
-
-	if (! g_file_move (directory_content, new_directory_content, 0, cancellable, NULL, NULL, &error)) {
-		g_warning ("%s", error->message);
-		g_clear_error (&error);
-	}
-
-	if (! g_file_delete (parent, cancellable, &error)) {
-		g_warning ("%s", error->message);
-		g_clear_error (&error);
-	}
-
-	fr_archive_set_last_extraction_destination (archive, new_directory_content);
-
-	g_object_unref (new_directory_content);
-	g_object_unref (parent_parent);
-	g_object_unref (parent);
-	g_object_unref (directory_content);
-}
-
-
 static void
 copy_extracted_files_done (GError   *error,
 			   gpointer  user_data)
@@ -267,9 +202,6 @@ copy_extracted_files_done (GError   *error,
 	_g_file_remove_directory (self->priv->temp_extraction_dir, NULL, NULL);
 	_g_clear_object (&self->priv->temp_extraction_dir);
 
-	if ((error == NULL) && (xfer_data->archive->extract_here))
-		move_here (xfer_data->archive, xfer_data->cancellable);
-
 	g_simple_async_result_complete_in_idle (xfer_data->result);
 
 	xfer_data_free (xfer_data);
@@ -327,7 +259,7 @@ fr_command_add (FrCommand  *self,
 		GList      *file_list,
 		GFile      *base_dir,
 		gboolean    update,
-		gboolean    recursive)
+		gboolean    follow_links)
 {
 	char *base_dir_path;
 
@@ -341,7 +273,7 @@ fr_command_add (FrCommand  *self,
 						     file_list,
 						     base_dir_path,
 						     update,
-						     recursive);
+						     follow_links);
 
 	g_free (base_dir_path);
 }
@@ -958,23 +890,13 @@ split_in_chunks (GList *file_list)
 }
 
 
-/* this is because the fr_archive_progress_inc_completed_files function is
- * called *before* the file is actually added/removed from the archive, adding
- * 1 to the totale we get for example a 50% (instead of 100%) progress when
- * adding a single file. */
-static int
-get_length_for_progress (int l)
-{
-	return (l > 0) ? l + 1 : 0;
-}
-
 static gboolean
 _fr_command_add (FrCommand      *self,
 		 GList          *file_list,
 		 GFile          *base_dir,
 		 const char     *dest_dir,
 		 gboolean        update,
-		 gboolean        recursive,
+		 gboolean        follow_links,
 		 const char     *password,
 		 gboolean        encrypt_header,
 		 FrCompression   compression,
@@ -1120,7 +1042,7 @@ _fr_command_add (FrCommand      *self,
 	/* add now. */
 
 	new_file_list_length = g_list_length (new_file_list);
-	fr_archive_progress_set_total_files (archive, get_length_for_progress (new_file_list_length));
+	fr_archive_progress_set_total_files (archive, new_file_list_length);
 
 	if (archive->propListFromFile && (new_file_list_length > LIST_LENGTH_TO_USE_FILE)) {
 		char   *list_dir;
@@ -1135,7 +1057,7 @@ _fr_command_add (FrCommand      *self,
 					new_file_list,
 					tmp_base_dir,
 					update,
-					recursive);
+					follow_links);
 
 			/* remove the temp dir */
 
@@ -1166,7 +1088,7 @@ _fr_command_add (FrCommand      *self,
 					chunk,
 					tmp_base_dir,
 					update,
-					recursive);
+					follow_links);
 			g_list_free (chunk);
 		}
 
@@ -1286,7 +1208,7 @@ _fr_command_add_local_files (FrCommand           *self,
 			     GFile               *base_dir,
 			     const char          *dest_dir,
 			     gboolean             update,
-			     gboolean             recursive,
+			     gboolean             follow_links,
 			     const char          *password,
 			     gboolean             encrypt_header,
 			     FrCompression        compression,
@@ -1307,7 +1229,7 @@ _fr_command_add_local_files (FrCommand           *self,
 			       base_dir,
 			       dest_dir,
 			       update,
-			       recursive,
+			       follow_links,
 			       password,
 			       encrypt_header,
 			       compression,
@@ -1354,8 +1276,8 @@ copy_remote_files_done (GError   *error,
 					     xfer_data->file_list,
 					     xfer_data->tmp_dir,
 					     xfer_data->dest_dir,
-					     FALSE,
-					     xfer_data->recursive,
+					     xfer_data->update,
+					     xfer_data->follow_links,
 					     xfer_data->password,
 					     xfer_data->encrypt_header,
 					     xfer_data->compression,
@@ -1388,7 +1310,7 @@ copy_remote_files (FrCommand           *self,
 		   GFile               *base_dir,
 		   const char          *dest_dir,
 		   gboolean             update,
-		   gboolean             recursive,
+		   gboolean             follow_links,
 		   const char          *password,
 		   gboolean             encrypt_header,
 		   FrCompression        compression,
@@ -1452,7 +1374,7 @@ copy_remote_files (FrCommand           *self,
 	xfer_data->base_dir = g_object_ref (base_dir);
 	xfer_data->dest_dir = g_strdup (dest_dir);
 	xfer_data->update = update;
-	xfer_data->recursive = recursive;
+	xfer_data->follow_links = follow_links;
 	xfer_data->dest_dir = g_strdup (dest_dir);
 	xfer_data->password = g_strdup (password);
 	xfer_data->encrypt_header = encrypt_header;
@@ -1485,7 +1407,7 @@ fr_command_add_files (FrArchive           *base,
 		      GFile               *base_dir,
 		      const char          *dest_dir,
 		      gboolean             update,
-		      gboolean             recursive,
+		      gboolean             follow_links,
 		      const char          *password,
 		      gboolean             encrypt_header,
 		      FrCompression        compression,
@@ -1508,7 +1430,7 @@ fr_command_add_files (FrArchive           *base,
 					     base_dir,
 					     dest_dir,
 					     update,
-					     recursive,
+					     follow_links,
 					     password,
 					     encrypt_header,
 					     compression,
@@ -1521,7 +1443,7 @@ fr_command_add_files (FrArchive           *base,
 				   base_dir,
 				   dest_dir,
 				   update,
-				   recursive,
+				   follow_links,
 				   password,
 				   encrypt_header,
 				   compression,
@@ -1613,7 +1535,7 @@ delete_from_archive (FrCommand *self,
 		g_list_free (file_list);
 
 	tmp_file_list_length = g_list_length (tmp_file_list);
-	fr_archive_progress_set_total_files (archive, get_length_for_progress (tmp_file_list_length));
+	fr_archive_progress_set_total_files (archive, tmp_file_list_length);
 
 	if (archive->propListFromFile && (tmp_file_list_length > LIST_LENGTH_TO_USE_FILE)) {
 		char *list_dir;
@@ -2166,9 +2088,9 @@ _fr_command_extract (FrCommand  *self,
 	}
 
 	if (extract_all && (file_list == NULL))
-		fr_archive_progress_set_total_files (archive, get_length_for_progress (archive->files->len));
+		fr_archive_progress_set_total_files (archive, archive->files->len);
 	else
-		fr_archive_progress_set_total_files (archive, get_length_for_progress (g_list_length (file_list)));
+		fr_archive_progress_set_total_files (archive, g_list_length (file_list));
 
 	if (all_options_supported) {
 		gboolean created_filtered_list = FALSE;
@@ -2351,8 +2273,6 @@ process_ready_for_extract_to_local_cb (GObject      *source_object,
 			xfer_data_free (xfer_data);
 			return;
 		}
-		else if (xfer_data->archive->extract_here)
-			move_here (xfer_data->archive, xfer_data->cancellable);
 	}
 	else {
 		g_simple_async_result_set_from_error (xfer_data->result, error);
@@ -2364,12 +2284,8 @@ process_ready_for_extract_to_local_cb (GObject      *source_object,
 			_g_file_remove_directory (self->priv->temp_extraction_dir, NULL, NULL);
 			_g_clear_object (&self->priv->temp_extraction_dir);
 		}
-
-		if (xfer_data->archive->extract_here)
-			_g_file_remove_directory (fr_archive_get_last_extraction_destination (xfer_data->archive), NULL, NULL);
 	}
 
-	xfer_data->archive->extract_here = FALSE;
 	g_simple_async_result_complete_in_idle (xfer_data->result);
 
 	_g_error_free (error);
@@ -2499,7 +2415,7 @@ fr_command_test_integrity (FrArchive           *archive,
 		      "filename", self->priv->local_copy,
 		      "password", password,
 		      NULL);
-	fr_archive_progress_set_total_files (archive, get_length_for_progress (0));
+	fr_archive_progress_set_total_files (archive, 0);
 
 	fr_process_clear (self->process);
 	fr_command_test (self);
@@ -2954,6 +2870,14 @@ fr_command_base_recompress (FrCommand *command)
 }
 
 
+static void
+fr_command_base_handle_error (FrCommand *command,
+			      FrError   *error)
+{
+	/* void */
+}
+
+
 static void
 fr_command_class_init (FrCommandClass *klass)
 {
@@ -2987,7 +2911,7 @@ fr_command_class_init (FrCommandClass *klass)
 	klass->test = NULL;
 	klass->uncompress = fr_command_base_uncompress;
 	klass->recompress = fr_command_base_recompress;
-	klass->handle_error = NULL;
+	klass->handle_error = fr_command_base_handle_error;
 
 	/* properties */
 
