@@ -32,9 +32,9 @@
 /* FileInfo */
 
 
-static FileInfo*
-_g_info_data_new (GFile     *file,
-		  GFileInfo *info)
+FileInfo *
+file_info_new (GFile     *file,
+	       GFileInfo *info)
 {
 	FileInfo *data;
 
@@ -46,21 +46,21 @@ _g_info_data_new (GFile     *file,
 }
 
 
-static void
-_g_info_data_free (FileInfo *info_data)
+void
+file_info_free (FileInfo *file_info)
 {
-	if (info_data == NULL)
+	if (file_info == NULL)
 		return;
-	_g_object_unref (info_data->file);
-	_g_object_unref (info_data->info);
-	g_free (info_data);
+	_g_object_unref (file_info->file);
+	_g_object_unref (file_info->info);
+	g_free (file_info);
 }
 
 
-static void
-_g_info_data_list_unref (GList *list)
+void
+file_info_list_free (GList *list)
 {
-	g_list_foreach (list, (GFunc) _g_info_data_free, NULL);
+	g_list_foreach (list, (GFunc) file_info_free, NULL);
 	g_list_free (list);
 }
 
@@ -143,7 +143,7 @@ static void
 _g_info_data_freev (FileInfo **data)
 {
 	if (*data != NULL)
-		_g_info_data_free (*data);
+		file_info_free (*data);
 	*data = NULL;
 }
 
@@ -184,7 +184,7 @@ for_each_child_data_free (ForEachChildData *fec)
 	_g_info_data_freev (&(fec->current));
 	g_free (fec->attributes);
 	if (fec->to_visit != NULL) {
-		g_list_foreach (fec->to_visit, (GFunc) _g_info_data_free, NULL);
+		g_list_foreach (fec->to_visit, (GFunc) file_info_free, NULL);
 		g_list_free (fec->to_visit);
 	}
 	_g_object_unref (fec->cancellable);
@@ -270,8 +270,7 @@ for_each_child_close_enumerator (GObject      *source_object,
 	{
 		if (fec->error == NULL)
 			fec->error = g_error_copy (error);
-		else
-			g_clear_error (&error);
+		g_clear_error (&error);
 	}
 
 	if ((fec->error == NULL) && fec->recursive)
@@ -300,20 +299,6 @@ for_each_child_read_next_files (ForEachChildData *fec)
 }
 
 
-static void for_each_child_read_current_child_metadata (ForEachChildData *fec);
-
-
-static void
-for_each_child_read_next_child_metadata (ForEachChildData *fec)
-{
-	fec->current_child = fec->current_child->next;
-	if (fec->current_child != NULL)
-		for_each_child_read_current_child_metadata (fec);
-	else
-		for_each_child_read_next_files (fec);
-}
-
-
 static void
 for_each_child_compute_child (ForEachChildData *fec,
 			      GFile            *file,
@@ -330,7 +315,7 @@ for_each_child_compute_child (ForEachChildData *fec,
 
 		if (g_hash_table_lookup (fec->already_visited, id) == NULL) {
 			g_hash_table_insert (fec->already_visited, g_strdup (id), GINT_TO_POINTER (1));
-			fec->to_visit = g_list_append (fec->to_visit, _g_info_data_new (file, info));
+			fec->to_visit = g_list_append (fec->to_visit, file_info_new (file, info));
 		}
 
 		g_free (id);
@@ -340,44 +325,6 @@ for_each_child_compute_child (ForEachChildData *fec,
 }
 
 
-static void
-for_each_child_metadata_ready_func (GObject      *source_object,
-                		    GAsyncResult *result,
-                		    gpointer      user_data)
-{
-	ForEachChildData *fec = user_data;
-	GFile            *file;
-	GFileInfo        *info;
-	GError           *error = NULL;
-
-	file = G_FILE (source_object);
-	info = g_file_query_info_finish (file, result, &error);
-	if (info != NULL)
-		for_each_child_compute_child (fec, file, info);
-
-	for_each_child_read_next_child_metadata (fec);
-}
-
-
-static void
-for_each_child_read_current_child_metadata (ForEachChildData *fec)
-{
-	GFileInfo *child_info = fec->current_child->data;
-	GFile     *child_file;
-
-	child_file = g_file_get_child (fec->current->file, g_file_info_get_name (child_info));
-	g_file_query_info_async  (child_file,
-				  fec->attributes,
-				  G_FILE_QUERY_INFO_NONE,
-				  G_PRIORITY_DEFAULT,
-				  NULL, /* FIXME: cannot use fec->cancellable here */
-				  for_each_child_metadata_ready_func,
-				  fec);
-
-	g_object_unref (child_file);
-}
-
-
 static void
 for_each_child_next_files_ready (GObject      *source_object,
 				 GAsyncResult *result,
@@ -393,7 +340,7 @@ for_each_child_next_files_ready (GObject      *source_object,
 	if (fec->children == NULL) {
 		g_file_enumerator_close_async (fec->enumerator,
 					       G_PRIORITY_DEFAULT,
-					       fec->cancellable,
+					       g_cancellable_is_cancelled (fec->cancellable) ? NULL : fec->cancellable,
 					       for_each_child_close_enumerator,
 					       fec);
 		return;
@@ -479,7 +426,7 @@ directory_info_ready_cb (GObject      *source_object,
 		return;
 	}
 
-	child = _g_info_data_new (fec->base_directory, info);
+	child = file_info_new (fec->base_directory, info);
 	g_object_unref (info);
 
 	for_each_child_set_current (fec, child);
@@ -576,7 +523,7 @@ static void
 query_data_free (QueryData *query_data)
 {
 	_g_object_list_unref (query_data->file_list);
-	_g_info_data_list_unref (query_data->files);
+	file_info_list_free (query_data->files);
 	_g_object_unref (query_data->cancellable);
 	g_free (query_data->attributes);
 	g_free (query_data);
@@ -626,7 +573,7 @@ query_data__for_each_file_cb (GFile      *file,
 	if ((query_data->file_filter_func != NULL) && query_data->file_filter_func (file, info, query_data->user_data))
 		return;
 
-	query_data->files = g_list_prepend (query_data->files, _g_info_data_new (file, info));
+	query_data->files = g_list_prepend (query_data->files, file_info_new (file, info));
 }
 
 
@@ -645,7 +592,7 @@ query_data__start_dir_cb (GFile       *file,
 	if ((query_data->directory_filter_func != NULL) && query_data->directory_filter_func (file, info, query_data->user_data))
 		return DIR_OP_SKIP;
 
-	query_data->files = g_list_prepend (query_data->files, _g_info_data_new (file, info));
+	query_data->files = g_list_prepend (query_data->files, file_info_new (file, info));
 
 	return DIR_OP_CONTINUE;
 }
@@ -662,8 +609,11 @@ query_data_info_ready_cb (GObject      *source_object,
 
 	info = g_file_query_info_finish ((GFile *) source_object, result, &error);
 	if (info == NULL) {
+		query_info__query_next (query_data);
+		/*
 		query_data->callback (NULL, error, query_data->user_data);
 		query_data_free (query_data);
+		*/
 		return;
 	}
 
@@ -679,7 +629,7 @@ query_data_info_ready_cb (GObject      *source_object,
 					   query_data);
 	}
 	else {
-		query_data->files = g_list_prepend (query_data->files, _g_info_data_new ((GFile *) query_data->current->data, info));
+		query_data->files = g_list_prepend (query_data->files, file_info_new ((GFile *) query_data->current->data, info));
 		query_info__query_next (query_data);
 	}
 
@@ -1059,7 +1009,7 @@ directory_copy_data_free (DirectoryCopyData *dcd)
 		g_object_unref (dcd->current_destination);
 		dcd->current_destination = NULL;
 	}
-	g_list_foreach (dcd->to_copy, (GFunc) _g_info_data_free, NULL);
+	g_list_foreach (dcd->to_copy, (GFunc) file_info_free, NULL);
 	g_list_free (dcd->to_copy);
 	g_free (dcd);
 }
@@ -1280,7 +1230,7 @@ g_directory_copy_for_each_file (GFile     *file,
 {
 	DirectoryCopyData *dcd = user_data;
 
-	dcd->to_copy = g_list_prepend (dcd->to_copy, _g_info_data_new (file, info));
+	dcd->to_copy = g_list_prepend (dcd->to_copy, file_info_new (file, info));
 	dcd->tot_files++;
 }
 
@@ -1293,7 +1243,7 @@ g_directory_copy_start_dir (GFile      *file,
 {
 	DirectoryCopyData *dcd = user_data;
 
-	dcd->to_copy = g_list_prepend (dcd->to_copy, _g_info_data_new (file, info));
+	dcd->to_copy = g_list_prepend (dcd->to_copy, file_info_new (file, info));
 	dcd->tot_files++;
 
 	return DIR_OP_CONTINUE;
